
From: Roman Zippel <zippel@linux-m68k.org>

Convert expression of the form (p->thread_info + 1) to use end_of_stack(),
which makes it also more readable.

Signed-off-by: Roman Zippel <zippel@linux-m68k.org>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 arch/arm/kernel/process.c |    2 +-
 arch/arm/kernel/traps.c   |    4 ++--
 arch/arm26/kernel/traps.c |    4 ++--
 arch/ppc/kernel/process.c |    2 +-
 4 files changed, 6 insertions(+), 6 deletions(-)

diff -puN arch/arm26/kernel/traps.c~use-end_of_stack arch/arm26/kernel/traps.c
--- 25/arch/arm26/kernel/traps.c~use-end_of_stack	Thu Sep  1 17:14:01 2005
+++ 25-akpm/arch/arm26/kernel/traps.c	Thu Sep  1 17:14:01 2005
@@ -158,7 +158,7 @@ void dump_backtrace(struct pt_regs *regs
 	} else if (verify_stack(fp)) {
 		printk("invalid frame pointer 0x%08x", fp);
 		ok = 0;
-	} else if (fp < (unsigned long)(tsk->thread_info + 1))
+	} else if (fp < (unsigned long)end_of_stack(tsk))
 		printk("frame pointer underflow");
 	printk("\n");
 
@@ -187,7 +187,7 @@ NORET_TYPE void die(const char *str, str
 	printk("CPU: %d\n", smp_processor_id());
 	show_regs(regs);
 	printk("Process %s (pid: %d, stack limit = 0x%p)\n",
-		current->comm, current->pid, tsk->thread_info + 1);
+		current->comm, current->pid, end_of_stack(tsk));
 
 	if (!user_mode(regs) || in_interrupt()) {
 		__dump_stack(tsk, (unsigned long)(regs + 1));
diff -puN arch/arm/kernel/process.c~use-end_of_stack arch/arm/kernel/process.c
--- 25/arch/arm/kernel/process.c~use-end_of_stack	Thu Sep  1 17:14:01 2005
+++ 25-akpm/arch/arm/kernel/process.c	Thu Sep  1 17:14:01 2005
@@ -448,7 +448,7 @@ unsigned long get_wchan(struct task_stru
 	if (!p || p == current || p->state == TASK_RUNNING)
 		return 0;
 
-	stack_start = (unsigned long)(p->thread_info + 1);
+	stack_start = (unsigned long)end_of_stack(p);
 	stack_end = ((unsigned long)p->thread_info) + THREAD_SIZE;
 
 	fp = thread_saved_fp(p);
diff -puN arch/arm/kernel/traps.c~use-end_of_stack arch/arm/kernel/traps.c
--- 25/arch/arm/kernel/traps.c~use-end_of_stack	Thu Sep  1 17:14:01 2005
+++ 25-akpm/arch/arm/kernel/traps.c	Thu Sep  1 17:14:01 2005
@@ -165,7 +165,7 @@ static void dump_backtrace(struct pt_reg
 	} else if (verify_stack(fp)) {
 		printk("invalid frame pointer 0x%08x", fp);
 		ok = 0;
-	} else if (fp < (unsigned long)(tsk->thread_info + 1))
+	} else if (fp < (unsigned long)end_of_stack(tsk))
 		printk("frame pointer underflow");
 	printk("\n");
 
@@ -216,7 +216,7 @@ NORET_TYPE void die(const char *str, str
 	print_modules();
 	__show_regs(regs);
 	printk("Process %s (pid: %d, stack limit = 0x%p)\n",
-		tsk->comm, tsk->pid, tsk->thread_info + 1);
+		tsk->comm, tsk->pid, end_of_stack(tsk));
 
 	if (!user_mode(regs) || in_interrupt()) {
 		dump_mem("Stack: ", regs->ARM_sp,
diff -puN arch/ppc/kernel/process.c~use-end_of_stack arch/ppc/kernel/process.c
--- 25/arch/ppc/kernel/process.c~use-end_of_stack	Thu Sep  1 17:14:01 2005
+++ 25-akpm/arch/ppc/kernel/process.c	Thu Sep  1 17:14:01 2005
@@ -638,7 +638,7 @@ void show_stack(struct task_struct *tsk,
 			sp = tsk->thread.ksp;
 	}
 
-	prev_sp = (unsigned long) (tsk->thread_info + 1);
+	prev_sp = (unsigned long)end_of_stack(tsk);
 	stack_top = (unsigned long) tsk->thread_info + THREAD_SIZE;
 	while (count < 16 && sp > prev_sp && sp < stack_top && (sp & 3) == 0) {
 		if (count == 0) {
_
